@@ -4,11 +4,11 @@ import json
 
 app = Flask(__name__)
 
-@app.route('/video/<id>')
+@app.route('/api/video/<id>')
 def index(id):
     data = YouTubeTranscriptApi.get_transcript(id, languages=['es'])
     transcription = json.dumps(data)
     return jsonify(transcription)
 
-def hi():
+def hi():                                               
     return "hola"
\ No newline at end of file
